@@ -19,17 +19,15 @@
 #include "config.h"
 
 #include <gtk/gtk.h>
-#include <libgnome/libgnome.h>
+#include <glib/gi18n.h>
 #include <gdk/gdkkeysyms.h>
 #include <string.h>
 #include <gdk/gdkx.h>
 #include <X11/XKBlib.h>
 
-#include "vicious.h"
 #include "greeter_parser.h"
 #include "greeter_item_capslock.h"
 
-
 static gboolean caps_lock_state = FALSE;
 
 static Display *
